@@ -7,7 +7,6 @@ import time
 import traceback
 import uuid
 from enum import Enum
-from typing import List, Optional, Union
 
 from rich.console import Console
 from rich.table import Table
@@ -336,7 +335,7 @@ class ScanQueue:
         self.scan_worker.start()
 
     @property
-    def worker_status(self) -> Union[None, InstructionQueueStatus]:
+    def worker_status(self) -> InstructionQueueStatus | None:
         """current status of the instruction queue"""
         if len(self.queue) > 0:
             return self.queue[0].status
@@ -455,7 +454,7 @@ class ScanQueue:
         if self.active_instruction_queue is not None:
             self.active_instruction_queue.abort()
 
-    def get_scan(self, scanID: str) -> Union[None, InstructionQueueItem]:
+    def get_scan(self, scanID: str) -> InstructionQueueItem | None:
         """get the instruction queue item based on its scanID"""
         queue_found = None
         for queue in self.history_queue + self.queue:
@@ -564,17 +563,17 @@ class RequestBlockQueue:
         self.scan_def_ids = {}
 
     @property
-    def scanID(self) -> List[str]:
+    def scanID(self) -> list[str]:
         """get the scanIDs for all request blocks"""
         return [rb.scanID for rb in self.request_blocks]
 
     @property
-    def is_scan(self) -> List[bool]:
+    def is_scan(self) -> list[bool]:
         """check if the request blocks describe scans"""
         return [rb.is_scan for rb in self.request_blocks]
 
     @property
-    def scan_number(self) -> List[int]:
+    def scan_number(self) -> list[int]:
         """get the list of scan numbers for all request blocks"""
         return [rb.scan_number for rb in self.request_blocks]
 
@@ -704,7 +703,7 @@ class InstructionQueueItem:
         self._return_to_start = None
 
     @property
-    def scan_number(self) -> List[int]:
+    def scan_number(self) -> list[int]:
         """get the scan numbers for the elements in this instruction queue"""
         return self.queue.scan_number
 
@@ -734,12 +733,12 @@ class InstructionQueueItem:
         return len(self.queue.scan_def_ids) == 0
 
     @property
-    def scanID(self) -> List[str]:
+    def scanID(self) -> list[str]:
         """get the scanIDs"""
         return self.queue.scanID
 
     @property
-    def is_scan(self) -> List[bool]:
+    def is_scan(self) -> list[bool]:
         """check whether the InstructionQueue contains scan."""
         return self.queue.is_scan
 
@@ -805,7 +804,7 @@ class InstructionQueueItem:
 
     def _get_next(
         self, queue="instructions", raise_stopiteration=True
-    ) -> Optional(messages.DeviceInstructionMessage):
+    ) -> messages.DeviceInstructionMessage | None:
         try:
             instr = next(self.queue)
             # instr = next(self.__getattribute__(queue))
