@@ -3,9 +3,8 @@ import threading
 import time
 import traceback
 from asyncio.log import logger
-from typing import List
 
-from bec_lib import Alarms, Device, MessageEndpoints, bec_logger, messages
+from bec_lib import Alarms, DeviceBase, MessageEndpoints, bec_logger, messages
 
 from .device_validation import DeviceValidation
 from .errors import DeviceMessageError, ScanAbortion
@@ -254,10 +253,7 @@ class ScanWorker(threading.Thread):
         self.device_manager.producer.send(
             MessageEndpoints.device_instructions(),
             messages.DeviceInstructionMessage(
-                device=baseline_devices,
-                action="read",
-                parameter=params,
-                metadata=instr.metadata,
+                device=baseline_devices, action="read", parameter=params, metadata=instr.metadata
             ).dumps(),
         )
 
@@ -329,13 +325,13 @@ class ScanWorker(threading.Thread):
             instr (DeviceInstructionMessage): Device instruction received from the scan assembler
 
         """
-        detectors = [dev.name for dev in self.device_manager.devices.detectors()]
+        async_devices = [dev.name for dev in self.device_manager.devices.async_devices()]
         devices = [
             dev.name
             for dev in self.device_manager.devices.enabled_devices
-            if dev.name not in detectors
+            if dev.name not in async_devices
         ]
-        for det in detectors:
+        for det in async_devices:
             self.device_manager.producer.send(
                 MessageEndpoints.device_instructions(),
                 messages.DeviceInstructionMessage(
@@ -345,7 +341,7 @@ class ScanWorker(threading.Thread):
                     metadata=instr.metadata,
                 ).dumps(),
             )
-        self._staged_devices.update(detectors)
+        self._staged_devices.update(async_devices)
 
         self.device_manager.producer.send(
             MessageEndpoints.device_instructions(),
@@ -357,7 +353,7 @@ class ScanWorker(threading.Thread):
             ).dumps(),
         )
         self._staged_devices.update(devices)
-        self._wait_for_stage(staged=True, devices=detectors, metadata=instr.metadata)
+        self._wait_for_stage(staged=True, devices=async_devices, metadata=instr.metadata)
         self._wait_for_stage(staged=True, devices=devices, metadata=instr.metadata)
 
     def unstage_devices(
@@ -381,10 +377,7 @@ class ScanWorker(threading.Thread):
         self.device_manager.producer.send(
             MessageEndpoints.device_instructions(),
             messages.DeviceInstructionMessage(
-                device=devices,
-                action="unstage",
-                parameter=parameter,
-                metadata=metadata,
+                device=devices, action="unstage", parameter=parameter, metadata=metadata
             ).dumps(),
         )
         if not cleanup:
@@ -400,14 +393,14 @@ class ScanWorker(threading.Thread):
 
     def _get_devices_from_instruction(
         self, instr: messages.DeviceInstructionMessage
-    ) -> List[Device]:
+    ) -> list[DeviceBase]:
         """Extract devices from instruction message
 
         Args:
             instr (DeviceInstructionMessage): DeviceInstructionMessage
 
         Returns:
-            List[Device]: List of devices
+            list[Device]: List of devices
         """
         devices = []
         if not instr.content.get("device"):
@@ -471,7 +464,10 @@ class ScanWorker(threading.Thread):
             self.connector.raise_alarm(
                 severity=Alarms.MAJOR,
                 source=instr.content,
-                content=f"Movement of device {failed_device[0]} failed whilst trying to reach the target position. Last recorded position: {last_pos}",
+                content=(
+                    f"Movement of device {failed_device[0]} failed whilst trying to reach the"
+                    f" target position. Last recorded position: {last_pos}"
+                ),
                 alarm_type="MovementFailed",
                 metadata=instr.metadata,
             )
@@ -504,10 +500,7 @@ class ScanWorker(threading.Thread):
             MessageEndpoints.device_req_status,
             messages.DeviceReqStatusMessage,
             instr.metadata,
-            [
-                self.validate.devices_returned_successfully,
-                self.validate.matching_requestID,
-            ],
+            [self.validate.devices_returned_successfully, self.validate.matching_requestID],
             wait_group_devices=wait_group_devices,
             instruction=instr,
         ):
@@ -541,9 +534,7 @@ class ScanWorker(threading.Thread):
             MessageEndpoints.device_status,
             messages.DeviceStatusMessage,
             instr.metadata,
-            [
-                self.validate.devices_are_idle,
-            ],
+            [self.validate.devices_are_idle],
             wait_group_devices=wait_group_devices,
         ):
             continue
@@ -573,10 +564,7 @@ class ScanWorker(threading.Thread):
             MessageEndpoints.device_staged,
             messages.DeviceStatusMessage,
             metadata,
-            [
-                stage_validator,
-                self.validate.matching_requestID,
-            ],
+            [stage_validator, self.validate.matching_requestID],
         ):
             continue
 
@@ -602,9 +590,7 @@ class ScanWorker(threading.Thread):
             MessageEndpoints.device_req_status,
             messages.DeviceReqStatusMessage,
             metadata,
-            [
-                self.validate.devices_returned_successfully,
-            ],
+            [self.validate.devices_returned_successfully],
             print_status=print_status,
         ):
             if time.time() - start > logger_update_delay:
@@ -624,11 +610,7 @@ class ScanWorker(threading.Thread):
         pipe = producer.pipeline()
         for readout, device in zip(readouts, devices):
             msg = messages.DeviceMessage(signals=readout, metadata=instr.metadata).dumps()
-            producer.set_and_publish(
-                MessageEndpoints.device_read(device),
-                msg,
-                pipe,
-            )
+            producer.set_and_publish(MessageEndpoints.device_read(device), msg, pipe)
         return pipe.execute()
 
     def _get_readback(self, devices: list) -> list:
@@ -680,17 +662,12 @@ class ScanWorker(threading.Thread):
             f"New scan status: {self.current_scanID} / {status} / {current_scan_info_print}"
         )
         msg = messages.ScanStatusMessage(
-            scanID=self.current_scanID,
-            status=status,
-            info=self.current_scan_info,
+            scanID=self.current_scanID, status=status, info=self.current_scan_info
         ).dumps()
         expire = None if status in ["open", "paused"] else 1800
         pipe = self.device_manager.producer.pipeline()
         self.device_manager.producer.set(
-            MessageEndpoints.public_scan_info(self.current_scanID),
-            msg,
-            pipe=pipe,
-            expire=expire,
+            MessageEndpoints.public_scan_info(self.current_scanID), msg, pipe=pipe, expire=expire
         )
         self.device_manager.producer.set_and_publish(MessageEndpoints.scan_status(), msg, pipe=pipe)
         pipe.execute()
